<?php
/**
 * WCFM plugin view
 *
 * WCFMvm Memberships Template
 *
 * @author 		WC Lovers
 * @package 	wcfmvm/templates
 * @version   1.0.0
 */

global $WCFM, $WCFMvm;

$member_id = get_current_user_id();

$member_info = wp_get_current_user();

$user_email = $current_user->user_email;
$first_name = $current_user->user_firstname;
$last_name  = $current_user->user_lastname;

$membership_id = get_user_meta( $member_id, 'temp_wcfm_membership', true );

if( !$membership_id ) return;

$membership_post = get_post( $membership_id );
$title = $membership_post->post_title;
$description = $membership_post->post_excerpt;

$features = (array) get_post_meta( $membership_id, 'features', true );
		
$subscription = (array) get_post_meta( $membership_id, 'subscription', true );
$is_free = isset( $subscription['is_free'] ) ? 'yes' : 'no';

$wcfm_membership_options = get_option( 'wcfm_membership_options', array() );
$membership_feature_lists = array();
if( isset( $wcfm_membership_options['membership_features'] ) ) $membership_feature_lists = $wcfm_membership_options['membership_features'];

$membership_payment_settings = array();
if( isset( $wcfm_membership_options['membership_payment_settings'] ) ) $membership_payment_settings = $wcfm_membership_options['membership_payment_settings'];
$paypal_email = ( $membership_payment_settings['paypal_email'] ) ? $membership_payment_settings['paypal_email'] : '';
$paypal_sandbox = isset( $membership_payment_settings['paypal_sandbox'] ) ? 'yes' : 'no';

if( ( $is_free != 'yes' ) && empty( $paypal_email ) ) {
	?>
	<div id="wcfmu-feature-missing-message" class="wcfm-warn-message wcfm-wcfmu" style="display: block;">
		<p><span class="fa fa-warning"></span>
		<?php _e( 'Something Wrong: You are not allowed to access this page now. Please contact Store Admin for more details.', 'wc-frontend-manager-vendor-membership' ); ?></p>
	</div>
	<?php
	return;
}

?>

<div id="wcfm_membership_container">
  <div class="wcfm_membership_review_pay">
		<div class="wcfm_membership_review_plan">
			<div class="wcfm_review_plan_welcome"><?php _e( 'Review your plan:', 'wc-frontend-manager-vendor-membership' ); ?></div>
			<div class="wcfm_review_plan_title"><?php echo $title; ?></div>
			<div class="wcfm_review_plan_description"><?php echo $description; ?></div>
			<div class="wcfm_review_plan_features">
			 <?php
			 if( !empty( $membership_feature_lists ) ) {
					foreach( $membership_feature_lists as $membership_feature_key => $membership_feature_list ) {
						if( isset( $membership_feature_list['feature'] ) && !empty( $membership_feature_list['feature'] ) ) {
							$feature_val = 'x';
							if( !empty( $features ) && isset( $features[$membership_feature_list['feature']] ) ) $feature_val = $features[$membership_feature_list['feature']];
							if( !$feature_val ) $feature_val = 'x';
							?>
							<div class="wcfm_review_plan_feature"><?php echo $membership_feature_list['feature']; ?></div>
							<div class="wcfm_review_plan_feature_val"><?php echo $feature_val; ?></div>
							<?php
						}
					}
			 }
			 ?>
		  </div>
		</div>
		
		<div class="wcfm_membership_pay">
		  <div class="wcfm_review_pay_welcome"><?php _e( 'Payment options:', 'wc-frontend-manager-vendor-membership' ); ?></div>
			<?php
			if( $is_free == 'yes' ) {
				?>
				<form id="wcfm_membership_payment_form" class="wcfm">
					<div class="wcfm_review_pay_free"><?php _e( 'FREE Plan!!! There is no payment option for this.', 'wc-frontend-manager-vendor-membership' ); ?></div>
					<input type="hidden" name="member_id" value="<?php echo $member_id; ?>" />
					<?php
				} else {
					$subscription_type = isset( $subscription['subscription_type'] ) ? $subscription['subscription_type'] : 'one_time';
					$one_time_amt = isset( $subscription['one_time_amt'] ) ? $subscription['one_time_amt'] : '1';
					$trial_amt = isset( $subscription['trial_amt'] ) ? $subscription['trial_amt'] : '';
					$trial_period = isset( $subscription['trial_period'] ) ? $subscription['trial_period'] : '';
					$trial_period_type = isset( $subscription['trial_period_type'] ) ? $subscription['trial_period_type'] : 'M';
					$billing_amt = isset( $subscription['billing_amt'] ) ? $subscription['billing_amt'] : '1';
					$billing_period = isset( $subscription['billing_period'] ) ? $subscription['billing_period'] : '1';
					$billing_period_type = isset( $subscription['billing_period_type'] ) ? $subscription['billing_period_type'] : 'M';
					$period_options = array( 'D' => __( 'Day(s)', 'wc-frontend-manager-vendor-membership' ), 'M' => __( 'Month(s)', 'wc-frontend-manager-vendor-membership' ), 'Y' => __( 'Year(s)', 'wc-frontend-manager-vendor-membership' ) );
					
					echo '<div class="wcfm_review_pay_paypal"><input type="radio" value="paypal" checked="true" />PayPal - '; 
					if( $subscription_type == 'one_time' ) {
						echo wc_price($one_time_amt);
						echo '<span class="wcfm_membership_price_description"> (' . __( 'One time payment', 'wc-frontend-manager-vendor-membership' ) . ')</span>';
					} else {
						echo wc_price($billing_amt);
						$price_description = sprintf( __( 'for each %s %s', 'wc-frontend-manager-vendor-membership' ), $billing_period, $period_options[$billing_period_type] );
						if( !empty( $trial_period ) && !empty( $trial_amt ) ) {
							$price_description .= ' ' . sprintf( __( 'with %s for first %s %s', 'wc-frontend-manager-vendor-membership' ), get_woocommerce_currency_symbol() . $trial_amt, $trial_period, $period_options[$trial_period_type] );
						}
						echo '<span class="wcfm_membership_price_description"> (' . $price_description . ')</span>';
					}
					echo "</div>";
					
					$WCFMvm->frontend->generate_paypal_request_form( $membership_id, $member_id );
				}
				?>
				
				<div class="wcfm-clearfix"></div>
				<div class="wcfm-message" tabindex="-1"></div>
				
				<div id="wcfm_membership_payment_submit" class="wcfm_form_simple_submit_wrapper">
					<input type="submit" name="save-data" value="<?php _e( 'Proceed', 'wc-frontend-manager-vendor-membership' ); ?>" id="wcfm_membership<?php if( $is_free != 'yes' ) echo '_paypal'; ?>_payment_button" class="wcfm_submit_button" />
				</div>
				<div class="wcfm-clearfix"></div>
			</form>
		</div>
	</div>
</div>

